==> kubernetes-model-4.1.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/HTTPIngressPathFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface HTTPIngressPathFluent<A extends HTTPIngressPathFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public IngressBackend getBackend();
    public IngressBackend buildBackend();
    public A withBackend(IngressBackend backend);
    public Boolean hasBackend();
    public HTTPIngressPathFluent.BackendNested<A> withNewBackend();
    public HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(IngressBackend item);
    public HTTPIngressPathFluent.BackendNested<A> editBackend();
    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackend();
    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(IngressBackend item);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();

    public interface BackendNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressBackendFluent<HTTPIngressPathFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}


}

==> kubernetes-model-4.4.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/HTTPIngressPathFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface HTTPIngressPathFluent<A extends HTTPIngressPathFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public IngressBackend getBackend();
    public IngressBackend buildBackend();
    public A withBackend(IngressBackend backend);
    public Boolean hasBackend();
    public HTTPIngressPathFluent.BackendNested<A> withNewBackend();
    public HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(IngressBackend item);
    public HTTPIngressPathFluent.BackendNested<A> editBackend();
    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackend();
    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(IngressBackend item);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);

    public interface BackendNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressBackendFluent<HTTPIngressPathFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}


}
